@@ -55,12 +55,12 @@
 
 /* VOID:UINT,UINT (./gucharmap-marshal.list:5) */
 void
-gucharmap_marshal_VOID__UINT_UINT (GClosure     *closure,
-                                   GValue       *return_value,
-                                   guint         n_param_values,
-                                   const GValue *param_values,
-                                   gpointer      invocation_hint,
-                                   gpointer      marshal_data)
+_gucharmap_marshal_VOID__UINT_UINT (GClosure     *closure,
+                                    GValue       *return_value,
+                                    guint         n_param_values,
+                                    const GValue *param_values,
+                                    gpointer      invocation_hint,
+                                    gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer     data1,
                                                 guint        arg_1,
